#
# spec file for package zchunk
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2020 Neal Gompa <ngompa13@gmail.com>.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global somajor 1
%global libname libzck%{somajor}
%global devname libzck-devel
Name:           zchunk
Version:        1.4.0
Release:        2.1
Summary:        Compressed file format that allows easy deltas
License:        BSD-2-Clause AND MIT
Group:          Productivity/Archiving/Compression
URL:            https://github.com/zchunk/zchunk
Source0:        %{url}/archive/%{version}/%{name}-%{version}.tar.gz
BuildRequires:  meson >= 0.44.0
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libzstd)
BuildRequires:  pkgconfig(openssl)
# ABI is unstable between components and ensures that patching doesn't break things
Requires:       %{libname} = %{version}-%{release}
Provides:       bundled(buzhash-urlblock) = 0.1

%description
zchunk is a compressed file format that splits the file into independent
chunks.  This allows you to only download the differences when downloading a
new version of the file, and also makes zchunk files efficient over rsync.
zchunk files are protected with strong checksums to verify that the file you
downloaded is in fact the file you wanted.

%package -n %{libname}
Summary:        Zchunk library
Group:          System/Libraries

%description -n %{libname}
zchunk is a compressed file format that splits the file into independent
chunks.  This allows you to only download the differences when downloading a
new version of the file, and also makes zchunk files efficient over rsync.
zchunk files are protected with strong checksums to verify that the file you
downloaded is in fact the file you wanted.

This package contains the zchunk library, libzck.

%package -n %{devname}
Summary:        Headers for building against zchunk
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{devname}
zchunk is a compressed file format that splits the file into independent
chunks.  This allows you to only download the differences when downloading a
new version of the file, and also makes zchunk files efficient over rsync.
zchunk files are protected with strong checksums to verify that the file you
downloaded is in fact the file you wanted.

This package contains the headers necessary for building against the zchunk
library, libzck.

%prep
%autosetup -p1
# Remove bundled sha libraries
rm -rf src/lib/hash/sha*

%build
%meson -Dwith-openssl=enabled -Dwith-zstd=enabled
%meson_build

%install
%meson_install
# Install dictionary generation script
mkdir -p %{buildroot}%{_libexecdir}
install -p contrib/gen_xml_dictionary %{buildroot}%{_libexecdir}/zck_gen_xml_dictionary
%if %{suse_version} >= 1600
%python3_fix_shebang_path %{buildroot}%{_libexecdir}/*
%endif

%check
%meson_test

%post -n   %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files
%license LICENSE
%doc README.md contrib
%{_bindir}/zck*
%{_bindir}/unzck
%{_libexecdir}/zck_gen_xml_dictionary
%{_mandir}/man1/unzck.1%{?ext_man}
%{_mandir}/man1/zck*.1%{?ext_man}

%files -n %{libname}
%license LICENSE
%{_libdir}/libzck.so.%{somajor}
%{_libdir}/libzck.so.%{version}

%files -n %{devname}
%doc zchunk_format.txt
%{_libdir}/libzck.so
%{_libdir}/pkgconfig/zck.pc
%{_includedir}/zck.h

%changelog
* Tue Feb 20 2024 pgajdos@suse.com
- remove dependency on /usr/bin/python3 using
  %%python3_fix_shebang_path macro, [bsc#1212476]
* Mon Jan 15 2024 Dirk Müller <dmueller@suse.com>
- update to 1.4.0:
  * Rework hash code to support openSSL 3.x EVP API
  * memory leak fix
  * tests for invalid zchunk files
  * More statistics in zchunk_delta_info
  * avoid infinite loop under certain conditions
  * Add zck_get_chunk_ctx function to get context from chunk
* Sat Oct 14 2023 Dirk Müller <dmueller@suse.com>
- update to 1.3.2:
  * Handle overflow errors in malformed zchunk files
* Sun Jun 11 2023 Dirk Müller <dmueller@suse.com>
- update to 1.3.1:
  * Fix read off-by-one bug in compressed int function
  * Handle read-data errors correctly
  * Ensure memory is freed when zrealloc is called with size 0
* Mon Mar 27 2023 Dirk Müller <dmueller@suse.com>
- update to 1.3.0:
  * Add ZCK_NO_WRITE option to disable writing to a file
  * meson: Use global function in argp check
* Sun Feb 19 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- update to 1.2.4:
  * Update tests to handle zstd 1.5.4
* Mon Oct 24 2022 Dirk Müller <dmueller@suse.com>
- update to 1.2.3:
  * Remove meson deprecation warning
  * Add license scan report and status
  * test/zck_cmp_uncomp: fix printf format types
  * meson: add option to build without docs
  * zck: declare write_data as static
* Fri Apr 22 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.2.2
  * Turn off EOL handling for the *.zck test files.
  * Let the tests also pass with libzstd-1.4.10.
* Thu Apr 14 2022 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.2.1
  * Better error detection
  * Add support for specifying compression-format in zck
  * zck: add option to select chunk hash
  * Fix testsuite: Add expected sha256sums for zstd 1.5.1+
  * Fix memory leaks
  * Various bug fixes
- Drop upstream merged zstd-1.5.1.patch
* Mon Jan  3 2022 Dirk Müller <dmueller@suse.com>
- add zstd-1.5.1.patch (gh#zchunk/zchunk/57)
* Thu Jun 24 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.1.16
  * Fix major bug when compressing with dictionary
* Fri May 21 2021 Ismail Dönmez <ismail@i10z.com>
- Update to version 1.1.14
  * Final fixes for zstd 1.5 support
* Sat May 15 2021 Ismail Dönmez <ismail@i10z.com>
- Update to version 1.1.12
  * Update testsuite for zstd 1.5
* Mon May  3 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.1.11
  * Fix memory leak of zck->prep_digest
  * Fix argp detection
  * Handle certain rare web servers that don't start with \r\n
- Drop upstream merged fix-test-argp.patch
* Mon Apr 26 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.1.9
  * Handle zstd 1.4.7+
  * Update documentation
  * unzck: require a *.zck extension
  * General bug fixes
- Dropped upstream merged
  d2eae512bee09a4047cfe586de12f644d73b0736.patch
- Add fix-test-argp.patch: Fix argp detection
* Mon Jan  4 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Add d2eae512bee09a4047cfe586de12f644d73b0736.patch: Fix build
  with zstd 1.4.7+.
* Sun Jan 19 2020 Neal Gompa <ngompa13@gmail.com>
- Update to version 1.1.5
  + Handle write errors correctly
* Wed Dec 18 2019 Martin Pluskal <mpluskal@suse.com>
- Update to version 1.1.4:
  * Simplify regex for detecting part header info
  * Fix coverity warnings
  * Open files with permissions 0666 and let umask(2) do its job.
  * Multipart boundary field can be quoted.
* Sun Mar 31 2019 Neal Gompa <ngompa13@gmail.com>
- Update to version 1.1.0
  + Fix multipart boundary bug when dealing with lighttpd servers
  + Optimize chunk matching while downloading, significantly reducing CPU usage
* Thu Jan 24 2019 Neal Gompa <ngompa13@gmail.com>
- Update to version 1.0.3
  + Fix some small bugs found by Coverity
  + Fix memory leak and off-by-one errors
- Drop patches part of 1.0.3 release
  + 0001-Fix-some-small-bugs-found-by-Coverity.patch
* Thu Jan 24 2019 Neal Gompa <ngompa13@gmail.com>
- Backport patch from upstream to fix bugs discovered by Coverity
  + Add patch: 0001-Fix-some-small-bugs-found-by-Coverity.patch
* Wed Jan 23 2019 Neal Gompa <ngompa13@gmail.com>
- Update to version 1.0.2
  + Use hash table for finding identical chunks, speeding up process
    considerably
  + Add test case to verify that identical chunk checking is working
* Mon Dec 17 2018 Neal Gompa <ngompa13@gmail.com>
- Update to version 0.9.17
  + Turn off some tests for big-endian architectures since zstd
    isn't deterministic on them
  + Add zck_gen_zdict binary to generate optimal zdict for a zchunk file
  + Add functions to API to simplify extracting a single chunk
  + Change default zstd compression to 9 for a 6x speed increase in
    compression speed for a 5%% increase in compression size
  + Switch from optional flags to more robust optional elements
  + Sanity check hex hashes passed in as an option
* Mon Oct 29 2018 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.9.13
  * Add read support for zchunk files with optional flags
  * Fix tests for zstd-1.3.6
* Sat Sep 29 2018 Neal Gompa <ngompa13@gmail.com>
- Bump meson build dependency to match meson.build requirement
* Sat Sep 29 2018 Neal Gompa <ngompa13@gmail.com>
- Rebase to 0.9.11
  + Fix small bug where creating a zck_dl context fails when zck
    context is NULL
  + Fix security bugs found by Coverity
  + Fix test failures for zstd <= 1.3.4
  + Add gen_xml_dictionary to libexecdir with zck_ prefix
  + Fix intermittent bug where auto-chunking wasn't deterministic
  + ABI (but not API change) - Use bool from stdbool.h
  + Allow specification of output file in zck
  + Set minimum and maximum chunk sizes for both automatic and
    manual chunking
  + New error handling functions
  + File format changes
  + API changes
- Make requirements between subpackages stricter to avoid issues
  due to inter-subpackage ABI/API changes
* Wed Jul 18 2018 Martin Pluskal <mpluskal@suse.com>
- Do not manually specify dependencies which are automatically
  generated
- Make requirements of devel package less strict
* Tue Jul 17 2018 Neal Gompa <ngompa13@gmail.com>
- Update to 0.7.6
  + SHA-512 and SHA-512/128 support
  + New default chunk checksum type SHA-512/128
  + Automatic chunking moved into libzck and is now default
  + New option to disable automatic chunking
  + Bugfixes
* Thu Jul  5 2018 Neal Gompa <ngompa13@gmail.com>
- Initial packaging based on Mageia package
